local RepCalc = CreateFrame("Frame")
RepCalc:RegisterEvent("ADDON_LOADED")
RepCalc:RegisterEvent("PLAYER_LOGOUT")
RepCalc:RegisterEvent("UPDATE_FACTION")
RepCalc:RegisterEvent("LFG_BONUS_FACTION_ID_UPDATED")
local RC_LDB = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("RepCalc", {
	type = "data source",
	icon = "Interface/ICONS/Achievement_Reputation_06",
	label = "RepCalc",
	OnClick = function(frame, button)
		if button == "LeftButton" then
			RepCalc.BrokerMenu()
		elseif button == "RightButton" then
			if not _G["RepCalc_Config"] then RepCalc.CreateConfig() end
			if not _G["RepCalc_Header"] then RepCalc.CreateBars() end
			if not RepCalcDB.RunSetup then 
				RepCalcDB.RunSetup = true
				RepCalc.FillConfig()
			else
				RepCalc.Hide()
			end
			RepCalc.ConfigShow()
		end
	end,
	OnTooltipShow = function(tt)
		tt:ClearLines()
		tt:AddLine("RepCalc")
		tt:AddLine("Left-Click to track a faction.")
		tt:AddLine("Right-Click to open the configuration.")
		if RepCalcDB.RepName then
			tt:AddLine(" ")
			local bonusName
			local bonusID = GetLFGBonusFactionID()
			if bonusID then bonusName = GetFactionInfoByID(bonusID) end
			for i = 1, 100 do
				if RepCalcDB.RepNum[i] == 1 then
					local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.RepName[i], RepCalcDB.RepID[i])
					local repPercent = ceil((earntVal/topVal)*100)
					local standColour = RepCalc.FindColour(topVal, totalReq)
					tt:AddDoubleLine("|cffffffff"..RepCalcDB.RepName[i]..": "..standColour..standName, earntVal.."/"..topVal.." ("..repPercent.."%)")
				end
			end
		end
	end,
})

local LegionReps = {1900,1883,1828,1859,1894,1948,1975,1984,2018,2045,2165,2170}
local WoDReps = {1740,1515,1731,1738,1733,1445,1847,1708,1741,1849,1710,1732,1711,1737,1850,1736,1739,1848,1681,1682}
local MoPReps = {1277,1440,1375,1275,1492,1283,1282,1228,1281,1269,1279,1273,1387,1358,1276,1376,1271,1242,1270,1435,1216,1278,1388,1302,1341,1359,1351,1337,1345,1272,1280}
local CataReps = {1204,1177,1172,1158,1178,1173,1135,1171,1174}
local WrathReps = {1037,1106,1068,1104,1052,1090,1098,1156,1126,1067,1073,1105,1094,1119,1124,1064,1091,1050,1085}
local BCReps = {1012,942,946,989,978,1011,1015,1038,1031,1077,970,932,933,941,990,934,935,967,947,922}

function RepCalc:OnEvent(event, addonName)
	if event == "ADDON_LOADED" and addonName == "RepCalc" then
		RepCalcDB = RepCalcDB or {}
		if RepCalcDB.RepName then
			if not RepCalcDB.RepID then RepCalcDB.RepID = {} end
			RepCalc.CreateBars()
			RepCalc.CreateConfig()
			RepCalcDB.RunSetup = true
			RepCalcDB.ConfigOpen = false
			RepCalc:UnregisterEvent("ADDON_LOADED")
		end
	elseif event == "PLAYER_LOGOUT" then
		if RepCalcDB and RepCalcDB.RepName and RepCalcDB.RepName[1] == nil then
			RepCalcDB = nil
			RepCalc:UnregisterEvent("PLAYER_LOGOUT")
		end
	elseif event == "UPDATE_FACTION" or event == "LFG_BONUS_FACTION_ID_UPDATED" then
		if RepCalcDB.RunSetup == true and RepCalcDB.Visible == true then 
			RepCalc.Update() 
		end
		if RepCalcDB.Tracked then
			local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.Tracked)
			local bonusID, bonusName = GetLFGBonusFactionID()
			if bonusID then bonusName = GetFactionInfoByID(bonusID) end
			if topVal then 
				local repPercent = ceil((earntVal/topVal)*100)
				local standColour = RepCalc.FindColour(topVal, totalReq)
				RC_LDB.text = RepCalcDB.Tracked..": "..standColour..earntVal.."/"..topVal.." ("..repPercent.."%)"
				if RepCalcDB.Tracked == bonusName then RC_LDB.text = RC_LDB.text.." *" end
			end
		end

	end
end
RepCalc:SetScript("OnEvent", RepCalc.OnEvent)

SLASH_REPCALC1 = '/repcalc';
function SlashCmdList.REPCALC(msg, editbox)
	if not _G["RepCalc_Config"] then RepCalc.CreateConfig() end
	if not _G["RepCalc_Header"] then RepCalc.CreateBars() end
	if not RepCalcDB.RunSetup then 
		RepCalc.ConfigShow()
		RepCalcDB.RunSetup = true
	elseif RepCalcDB.ConfigOpen == false then
		RepCalc.Update()
	end
end

SLASH_RCCONFIG1 = '/rcconfig';
function SlashCmdList.RCCONFIG(msg, editbox)
	if not _G["RepCalc_Config"] then RepCalc.CreateConfig() end
	if not _G["RepCalc_Header"] then RepCalc.CreateBars() end
	if not RepCalcDB.RunSetup then 
		RepCalcDB.RunSetup = true
		RepCalc.FillConfig()
	else 
		RepCalc.Hide()
	end
	RepCalc.ConfigShow()
end

function RepCalc.FindColour(topVal, totalReq)
	local standColour
	if topVal == 8400 then --Colouring
		if totalReq < 8400 then standColour = "|cFF9370DB"--Good/Best Friend
		elseif totalReq >= 8400 and totalReq < 16800 then standColour = "|cFF1E90FF"--Friend
		elseif totalReq >= 16800 and totalReq < 25200 then standColour = "|cff00ff00"--Buddy
		elseif totalReq >= 25200 and totalReq < 33600 then standColour = "|cFFF4A460"--Acquaintance
		else standColour = "|cFFF4A460" end--Stranger
	elseif topVal == 10000 then
		if totalReq > 10000 then standColour = "|cff00ff00"--Bodyguard-1
		else standColour = "|cFF1E90FF" end --Bodyguard-2
	else 
		if topVal == 3000 then standColour = "|cFFF4A460"--Neutral
		elseif topVal == 6000 then standColour = "|cff00ff00"--Friendly
		elseif topVal == 12000 then standColour = "|cFF1E90FF"--Honored
		else standColour = "|cFF9370DB" end--Revered/Exalted
	end
	return standColour
end

function RepCalc.BrokerMenu()
	local faction, menu, repFound = {}, {}
	if RepCalcDB.RepNum then 
		for i = 1, 100 do 
			if RepCalcDB.RepNum[i] == 1 then repFound = 1; break end
		end 
	end
	if repFound then
		faction.text = "RepCalc: Choose Faction to Track"
		faction.isTitle = true; faction.notCheckable = true
		tinsert(menu, faction)
		local bonusName
		local bonusID = GetLFGBonusFactionID()
		if bonusID then bonusName = GetFactionInfoByID(bonusID) end
		for i = 1, 100 do
			if RepCalcDB.RepNum[i] == 1 then
				faction = {}
				local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.RepName[i], RepCalcDB.RepID[i])
				local repPercent = ceil((earntVal/topVal)*100)

				faction.checked = false; faction.hasArrow = false
				if RepCalcDB.RepName[i] == RepCalcDB.Tracked then faction.checked = true end

				local standColour = RepCalc.FindColour(topVal, totalReq)
				faction.text = RepCalcDB.RepName[i]..": "..standColour.." ("..earntVal.."/"..topVal..") "..standName

				if RepCalcDB.RepName[i] == bonusName then faction.text = faction.text.." *" end

				faction.func = function()
					local bonusID, bonusName = GetLFGBonusFactionID()
					if bonusID then bonusName = GetFactionInfoByID(bonusID) end

					local standColour = RepCalc.FindColour(topVal, totalReq)
					RC_LDB.text = RepCalcDB.RepName[i]..": "..standColour..earntVal.."/"..topVal.." ("..repPercent.."%)"
					if RepCalcDB.RepName[i] == bonusName then RC_LDB.text = RC_LDB.text.." *" end
					RepCalcDB.Tracked = RepCalcDB.RepName[i] 
				end
				tinsert(menu, faction)
			end
		end
		faction = {}
		faction.checked = false; faction.hasArrow = false; faction.text = "** Disable Tracking"
		faction.func = function() RC_LDB.text = "RepCalc"; RepCalcDB.Tracked = nil end
		tinsert(menu, faction)

	else
		faction.text = "RepCalc: No factions currently being tracked."
		faction.isTitle = true; faction.notCheckable = true
		tinsert(menu, faction)
	end
	local menuFrame = CreateFrame("Frame", "RepCalc_Menu", UIParent, "UIDropDownMenuTemplate")
	menuFrame:Hide()
	EasyMenu(menu, menuFrame, "cursor", 0 , 0, "MENU")
end

function RepCalc.CreateConfig()
	local fra = CreateFrame("Frame", "RepCalc_Config", UIParent)
	fra:SetFrameStrata("DIALOG")
	fra:SetMovable(true)
	fra:EnableMouse(true)
	fra:RegisterForDrag("LeftButton")
	fra:SetScript("OnDragStart", fra.StartMoving)
	fra:SetScript("OnDragStop", fra.StopMovingOrSizing)
	fra:SetPoint("CENTER")
	fra:SetSize(366, 506)
	fra:Hide()
	local tex = fra:CreateTexture("ARTWORK")
	tex:SetAllPoints()
	tex:SetColorTexture(0,0,0,0.9)
	tex:SetPoint("TOPLEFT", fra, 2, -2); tex:SetPoint("BOTTOMRIGHT", fra, -2, 2)
	local scrFra = CreateFrame("ScrollFrame", "RepCalc_ScrollFrame", fra)
	scrFra:SetPoint("TOPLEFT", 8, -48)
	scrFra:SetPoint("BOTTOMRIGHT", -5, 10)
	fra.scrollframe = scrFra
	local scrBar = CreateFrame("Slider", "RepCalc_Slider", scrFra, "UIPanelScrollBarTemplate")
	scrBar:SetPoint("TOPLEFT", fra, "TOPRIGHT", -19, -19)
	scrBar:SetPoint("BOTTOMLEFT", fra, "BOTTOMRIGHT", 19, 19)
	scrBar:SetMinMaxValues(1, 100)
	scrBar:SetValueStep(46)
	scrBar:SetValue(0)
	scrBar:SetWidth(16)
	scrBar:SetScript("OnValueChanged", function (self, value) self:GetParent():SetVerticalScroll(value) end)
	fra.scrollbar = scrBar 
	scrFra:EnableMouseWheel(true)
	scrFra:SetScript("OnMouseWheel",
		function(self, delta) 
			local x = scrBar:GetValue(); local y = scrBar:GetValueStep()
			if #RepCalcDB.RepName > 22 then -- Only work if scrollbar is up
				if delta == 1 then scrBar:SetValue(x-y)
				else scrBar:SetValue(x+y) end 
			end
	end)
	local scrContent = CreateFrame("Frame", "RepCalc_Content", scrFra)
	scrContent:SetSize(128, 128)
	scrFra.content = scrContent 
	scrFra:SetScrollChild(scrContent)
	local backdrop = { -- Border
	  edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	  tile = false, tileSize = 8, edgeSize = 8,
	  insets = { left = 2, right = 2, top = 2, bottom = 2 }
	}
	fra:SetBackdrop(backdrop)
	fra:SetBackdropBorderColor(1, 1, 1, 1)
	local ttl = fra:CreateFontString("$parent_HeaderText","OVERLAY","GameFontNormal") -- Header Text
	ttl:SetPoint("TOPLEFT",fra,"TOPLEFT",9,-6)
	ttl:SetText("RepCalc Configuration")
	ttl:Show()
	local ttle = scrContent:CreateFontString("TitleError","OVERLAY","GameFontNormalSmall") --Error Text
	ttle:SetPoint("TOPLEFT",scrContent,"TOPLEFT",6,-62)
	ttle:SetText("No honored or revered reputations found.")
	ttle:Hide()
	local desc = fra:CreateFontString("HeaderDesc","OVERLAY","GameFontNormalSmall") --Help Text
	desc:SetPoint("TOPLEFT",fra,"TOPLEFT",8,-20)
	desc:SetText("Select reputations to track (10 maximum).\nKey: |cff00ff00Legion, |cFFF4A460Draenor, |cff00FF7FPandaria, |cFFFF6060Cataclysm, |cFF1E90FFWrath, |cFF9370DBB.Crusade")
	desc:SetJustifyH("LEFT")
	local btn = CreateFrame("Button","RepCalc_ConfigButton",fra,"UIPanelButtonTemplate") --Save Button
	btn:SetSize(60, 23)
	btn:SetPoint("TOPRIGHT",fra,"TOPRIGHT",-25,-4)
	btn:SetText("Save")
	btn:SetScript("OnClick", function (self, button, down) if button == "LeftButton" then RepCalc.ConfigButton() end end)
	btn:Show()
	--Checkboxes
	local x, y = 0, 0
	for i = 1, 100 do
		local chkBox = CreateFrame("CheckButton", "RepCalc_Config_CheckButton"..i, scrContent, "UICheckButtonTemplate")
		local chkText =  _G[chkBox:GetName().."Text"]
		chkBox:SetSize(25, 25)
		chkText:SetJustifyH("Left")
		chkText:SetSize(150,25)
		chkBox:SetPoint("TOPLEFT",scrContent,"TOPLEFT",x, y)
		--StatusBar
		local barFra = CreateFrame("Frame","RepCalc_Config_StatusFrame"..i,scrContent)
		local bar = CreateFrame("StatusBar", "RepCalc_Config_StatusBar"..i, barFra)
		local barText = bar:CreateFontString("RepCalc_Config_BarText"..i,"OVERLAY","GameFontNormalSmall")
		local tex = barFra:CreateTexture("ARTWORK")
		tex:SetColorTexture(0,0,0,1)
		tex:SetPoint("TOPLEFT", barFra, 3, -3); tex:SetPoint("BOTTOMRIGHT", barFra, -3, 3)
		barFra:SetSize(145,22)
		barFra:SetPoint("TOPLEFT",chkBox,"TOPRIGHT",160, -2)
		barText:SetPoint("TOPLEFT",barFra,"TOPLEFT",5,-6)
		bar:SetSize(138, 16)
		bar:SetPoint("TOPLEFT",barFra,"TOPLEFT",3, -4)
		bar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		bar:SetMinMaxValues(0, 100)
		bar:SetStatusBarColor(0, 0.6, 0, 1)
		local backdrop = {
		  edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		  tile = false, tileSize = 12, edgeSize = 12,
		  insets = { left = 3, right = 3, top = 3, bottom = 3 }
		}
		barFra:SetBackdrop(backdrop)
		barFra:SetBackdropBorderColor(1, 1, 1, 1)
		y=y-25
	end
	local ttle = fra:CreateFontString("TitleError","OVERLAY","GameFontNormalSmall") --Error Text
	ttle:SetPoint("TOPLEFT",scrContent,"TOPLEFT",6,-62)
	ttle:SetText("No honored or revered reputations found.")
	ttle:Hide()
end

function RepCalc.CreateBars()
	local fra = CreateFrame("Frame","RepCalc_Header",UIParent) -- Header
	fra:SetSize(215, 23)
	fra:SetFrameStrata("MEDIUM")
	fra:SetMovable(true)
	fra:EnableMouse(true)
	fra:RegisterForDrag("LeftButton")
	fra:SetScript("OnDragStart", fra.StartMoving)
	fra:SetScript("OnDragStop", fra.StopMovingOrSizing)
	fra:SetScript("OnMouseUp", function (self, button) if button == "RightButton" then RepCalc.Hide(); RepCalc.ConfigShow() end end)
	fra:SetPoint("CENTER")
	fra:Hide()
	local tex = fra:CreateTexture("$parent_Background","ARTWORK")
	tex:SetAllPoints()
	tex:SetColorTexture(0, 0, 0, 0.7)
	local ttl = fra:CreateFontString("HeaderText","OVERLAY","GameFontNormal") --Title
	ttl:SetPoint("TOPLEFT",fra,"TOPLEFT",4,-5)
	ttl:SetText("RepCalc")
	local btn = CreateFrame("Button","$parent_CloseButton",fra,"UIPanelCloseButton") --Close Button
	btn:SetPoint("TOPRIGHT",fra,"TOPRIGHT",5,5)
	btn:SetScript("OnClick", function (self, button, down) if button == "LeftButton" then RepCalc.Hide() end end)
	btn:Show()
	local fraTop, fraBelow = fra
	for i = 1, 10 do --Rep Bars
		fraBelow = CreateFrame("Frame","RepCalc_Frame"..i,fra)
		fraBelow:SetFrameStrata("LOW")
		fraBelow:SetPoint("TOPLEFT",fraTop,"BOTTOMLEFT",0,0)
		fraBelow:SetSize(215, 25)
		fraBelow:SetScript("OnMouseUp", function(self, button) 
			if button == "LeftButton" then RepCalc.ShowRep(i) 
			elseif button == "RightButton" then RepCalc.SetLFG(i) end
		end)
		fraBelow:Hide()
		local tex = fraBelow:CreateTexture("$parent_Background","BACKGROUND")
		tex:SetAllPoints(fraBelow)
		tex:SetColorTexture(0, 0, 0, 0.6)
		local fraStar = CreateFrame("Frame","RepCalc_Star"..i,fraBelow) --Star
		fraStar:SetFrameStrata("HIGH")
		fraStar.texture = fraStar:CreateTexture()
		fraStar:SetSize(12,12)
		fraStar:SetPoint("RIGHT",fraBelow,"RIGHT",-2,0)
		fraStar.texture:SetTexture("Interface\\Common\\ReputationStar", "MEDIUM")
		fraStar.texture:SetAllPoints(fraStar)
		fraStar.texture:SetTexCoord(0,0.5,0,0.5)
		fraStar:Hide()
		local bar = CreateFrame("StatusBar", "RepCalc_StatusBar"..i, fraBelow) --StatusBar
		bar:SetSize(212, 25)
		bar:SetAllPoints("RepCalc_Frame"..i)
		bar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		bar:SetMinMaxValues(0, 1000)
		bar:SetStatusBarColor(0, 0.6, 0, 1)
		bar:Show()
		local barText = bar:CreateFontString("RepCalc_StatusBar"..i.."Text",nil,"GameFontNormalSmall") --StatusBar Text
		barText:SetPoint("TOPLEFT",bar,"TOPLEFT",3,1)
		barText:SetSize(212, 25)
		barText:SetJustifyH("LEFT"); barText:SetJustifyV("MIDDLE")
		barText:SetAlpha(1)
		barText:Show()
		fraTop = fraBelow
	end
end

function RepCalc.SetLFG(num)
	local x, y = 0, 0
	for i = 1, 100 do
		if RepCalcDB.RepNum[i] == 1 then x=x+1 end
		if x == num then y = i; break end
	end
	local _, _, _, _, _, _, _, _, _, _, _, _, _, _, _, LFDBonus = GetFactionInfoByID(RepCalcDB.RepID[y])
	if LFDBonus then
		for i = 1, 10 do _G["RepCalc_Star"..i]:Hide() end
		SetLFGBonusFactionID(RepCalcDB.RepID[y])
		RepCalc.Update() 
	end
end

function RepCalc.Hide()
	RepCalcDB.Visible = false
	local fHeader = _G["RepCalc_Header"]
	fHeader:Hide()
	for i = 1, 10 do
		local f = _G["RepCalc_Frame"..i]
		f:Hide()
	end
end

function RepCalc.ConfigShow()
	local fConfig = _G["RepCalc_Config"]
	RepCalc.FillConfig()
	fConfig:Show()
	RepCalcDB.ConfigOpen = true
end

function RepCalc.ConfigHide()
	local fConfig = _G["RepCalc_Config"]
	fConfig:Hide()
	RepCalcDB.ConfigOpen = false
end

function RepCalc.MakeBar(barNum, repNum)--(num, value)
	local topVal, earntVal, totalReq, standName, hasBonus, isLFG = RepCalc.CalcRep(RepCalcDB.RepName[repNum], RepCalcDB.RepID[repNum])
	if earntVal == 0 and topVal == 0 then return end
	local repPercent = (earntVal / topVal)*1000
	local repText = RepCalcDB.RepName[repNum].."\n"..standName.." ("..earntVal.."/"..topVal..")"
	local bar = _G["RepCalc_StatusBar"..barNum]
	local barText = _G["RepCalc_StatusBar"..barNum.."Text"]
	bar:SetValue(repPercent)
	barText:SetText(repText)
	if topVal == 8400 then --Colouring
		if totalReq < 8400 then bar:SetStatusBarColor(0, 0.5, 0, 1)--Good/Best Friend
		elseif totalReq >= 8400 and totalReq < 16800 then bar:SetStatusBarColor(0, 0.6, 0, 1)--Friend
		elseif totalReq >= 16800 and totalReq < 25200 then bar:SetStatusBarColor(0, 0.6, 0, 1)--Buddy
		elseif totalReq >= 25200 and totalReq < 33600 then bar:SetStatusBarColor(0, 0.7, 0, 1)--Acquaintance
		else bar:SetStatusBarColor(0.7, 0.4, 0, 1) end--Stranger
	else
		if topVal == 3000 then bar:SetStatusBarColor(0.7,0.4,0,1)--Neutral
		elseif topVal == 6000 then bar:SetStatusBarColor(0,0.7,0,1)--Friendly
		elseif topVal == 12000 then bar:SetStatusBarColor(0,0.6,0,1)--Honored
		else bar:SetStatusBarColor(0,0.5,0,1) end--Revered/Exalted
	end
	if isLFG then _G["RepCalc_Star"..barNum]:Show() else _G["RepCalc_Star"..barNum]:Hide() end--LFD bonus
end

function RepCalc.CreateDB()
	local tempRepDB, repReq = {}
	RepCalcDB.RepName, RepCalcDB.RepNum, RepCalcDB.RepStand, RepCalcDB.RepID = {}, {}, {}, {}
	for idx = 1, 200 do --Create unsorted DB
		local name, _, _, barMin, barMax, barValue, _, _, isHeader, _, hasRep, _, _, factID = GetFactionInfo(idx)
		if not name or name == "Inactive" then break end
		if barValue >= 0 and barValue < 42000 and (not isHeader or hasRep) and factID ~= 1691 and factID ~= 1419 and factID ~= 1169 and factID ~= 1690 and factID ~= 1374 and factID ~= 1834 and factID ~= 2011 then
			local skipRep = false
			if barMin == 20000 and barValue == 20000 then
				skipRep = true --Exalted Bodyguard
			elseif (barMax - barMin) == 10000 then
				repReq = 20000 - barValue --Bodyguard
			else repReq = 42000 - barValue end
			if not skipRep then tempRepDB[name] = repReq end
		end
		if barValue >= 42000 then
			local hasParagon = C_Reputation.IsFactionParagon(factID)
			if hasParagon then
				local curVal, _, _, _ = C_Reputation.GetFactionParagonInfo(factID)
				curVal = mod(curVal, 10000)
				repReq = 0 - curVal; tempRepDB[name] = repReq
			end
		end
	end
	local idx = 0
	for _ in pairs(tempRepDB) do idx=idx+1 end --Count reps
	local repName, repTotal, fRepeat --Sort into new DB
	for i = 1, idx do
		for k, v in pairs(tempRepDB) do
			fRepeat = false
			for i = 1, #RepCalcDB.RepName do
				if RepCalcDB.RepName[i] == k then fRepeat = true end
			end
			if fRepeat == false then
				if not repTotal then repName = k; repTotal = v;
				elseif v <= repTotal then repName = k; repTotal = v end
			end
		end
		RepCalcDB.RepName[i] = repName
		RepCalcDB.RepNum[i] = 0
		for x = 1, 200 do --Standing Name
			local name, _, standingID, _, _, _, _, _, _, _, _, _, _, factionID = GetFactionInfo(x)
			local _, friendRep, _, _, _, _, friendReaction = GetFriendshipReputation(factionID)
			RepCalcDB.RepID[i] = factionID
			if name == RepCalcDB.RepName[i] then
				if friendRep then RepCalcDB.RepStand[i] = friendReaction
				elseif C_Reputation.IsFactionParagon(factionID) then RepCalcDB.RepStand[i] = "Paragon"
				else RepCalcDB.RepStand[i] = GetText("FACTION_STANDING_LABEL"..standingID, gender) end
				break
			end
		end
		repName = nil; repTotal = nil
	end
end

function RepCalc.FillConfig()
	local trackedReps, repPercent = {}, 0
	if RepCalcDB.RepNum then 
		for i = 1, #RepCalcDB.RepNum do --Save tracked factions
			if RepCalcDB.RepNum[i] == 1 then tinsert(trackedReps, RepCalcDB.RepName[i]) end
		end
	end
	RepCalc.CreateDB() --Create faction database
	for i = 1, 100 do --Uncheck boxes
		local chkBox = _G["RepCalc_Config_CheckButton"..i]
		chkBox:SetChecked(false)
	end
	for i = 1, #RepCalcDB.RepName do
		local chkBox = _G["RepCalc_Config_CheckButton"..i]
		local chkTextBox =  _G[chkBox:GetName().."Text"]
		local statFra = _G["RepCalc_Config_StatusFrame"..i]
		local statBar = _G["RepCalc_Config_StatusBar"..i]
		local statText = _G["RepCalc_Config_BarText"..i]
		local repID = RepCalcDB.RepID[i]
		local name, _, standingID, barMin, barMax, barValue = GetFactionInfoByID(repID)
		local friendID, friendRep = GetFriendshipReputation(repID)
		local currentValue, threshold, rewardQuestID, hasRewardPending = C_Reputation.GetFactionParagonInfo(repID)
		if currentValue then currentValue = mod(currentValue, 10000) end
		if friendRep and (barMax-barMin) ~= 10000 then repPercent = ceil(((barValue - barMin)/8400)*100)
		elseif currentValue then repPercent = ceil((currentValue/10000)*100)
		elseif (barMax-barMin) == 10000 then repPercent = ceil(((barValue - barMin)/10000)*100)
		else repPercent = ceil((barValue-barMin)/(barMax-barMin)*100) end
		statFra:Show()
		statBar:SetValue(repPercent)
		statText:SetText(RepCalcDB.RepStand[i].." ("..repPercent.."%)")
		chkTextBox:SetText(RepCalcDB.RepName[i])
		local chkText = chkTextBox:GetText()
		--Colour the Factions
		for x = 1, #LegionReps do if RepCalcDB.RepID[i] == LegionReps[x] then chkTextBox:SetText("|cff00ff00"..chkText) end end
		for x = 1, #WoDReps do if RepCalcDB.RepID[i] == WoDReps[x] then chkTextBox:SetText("|cFFF4A460"..chkText) end end
		for x = 1, #MoPReps do if RepCalcDB.RepID[i] == MoPReps[x] then chkTextBox:SetText("|cff00FF7F"..chkText) end end
		for x = 1, #CataReps do if RepCalcDB.RepID[i] == CataReps[x] then chkTextBox:SetText("|cFFFF6060"..chkText) end end
		for x = 1, #WrathReps do if RepCalcDB.RepID[i] == WrathReps[x] then chkTextBox:SetText("|cFF1E90FF"..chkText) end end
		for x = 1, #BCReps do if RepCalcDB.RepID[i] == BCReps[x] then chkTextBox:SetText("|cFF9370DB"..chkText) end end
		chkBox:Show()
		chkBox:SetChecked(false)
		if #trackedReps > 0 then
			for x = 1, #trackedReps do --Tick previously tracked
				if trackedReps[x] == RepCalcDB.RepName[i] then chkBox:SetChecked(true) end
			end
		end
	end
	for i = 1, 100 do -- Hide unused
		if not RepCalcDB.RepName[i] then
			local chkBox = _G["RepCalc_Config_CheckButton"..i]
			local bar = _G["RepCalc_Config_StatusFrame"..i]
			if chkBox then chkBox:Hide() end
			if bar then bar:Hide() end
		end
	end
	local errString = _G["TitleError"] -- Hide/Show error text if no reps
	if #RepCalcDB.RepName < 1 then errString:Show()	else errString:Hide() end
	local scrBar = _G["RepCalc_Slider"] --Scrollbar
	local confButton = _G["RepCalc_ConfigButton"]
	local x = (#RepCalcDB.RepName * 25)-448
	if #RepCalcDB.RepName <= 22 then 
		x = 100
		scrBar:Hide()
		confButton:SetPoint("TOPRIGHT","RepCalc_Config","TOPRIGHT",-2,-2)
	else  
		scrBar:Show()
		confButton:SetPoint("TOPRIGHT","RepCalc_Config","TOPRIGHT",-20,-2)
	end
	scrBar:SetMinMaxValues(1, x)
	scrBar:SetValueStep((x/10)-1)
end

function RepCalc.ConfigButton()
	if RepCalcDB.RepName[1] then
		local maxNum,repFound = 1, 0
		for i = 1, 100 do
			if maxNum > 10 then maxNum=i; break end --Maximum 10 reps
			if not RepCalcDB.RepName[i] then break end
			local chkBox = _G["RepCalc_Config_CheckButton"..i]
			if chkBox:GetChecked() then RepCalcDB.RepNum[i] = 1; maxNum=maxNum+1 else RepCalcDB.RepNum[i] = 0 end
			if RepCalcDB.RepName[i] == RepCalcDB.Tracked then 
				if RepCalcDB.RepNum[i] == 1 then repFound = 1 else repFound = 0 end
			end
		end
		if repFound == 0 then RC_LDB.text = "RepCalc"; RepCalcDB.Tracked = nil end
		for i = maxNum, 100 do --Uncheck boxes past 10 max
			local chkBox = _G["RepCalc_Config_CheckButton"..i]
			if chkBox then chkBox:SetChecked(false) end
		end
		RepCalc.Update()
	else
		RepCalcDB.RunSetup = nil
	end
	RepCalc.ConfigHide()
end

function RepCalc.Update()
	local barNum = 1
	RepCalcDB.Visible = true
	_G["RepCalc_Header"]:Show()
	for i = 1, 10 do _G["RepCalc_Star"..i]:Hide() end
	for i = 1, 100 do
		if RepCalcDB.RepNum and RepCalcDB.RepNum[i] == 1 then
			local topVal, earntVal, totalReq = RepCalc.CalcRep(RepCalcDB.RepName[i], RepCalcDB.RepID[i])
			local f = _G["RepCalc_Frame"..barNum]
			if barNum <= 10 then
				if topVal then -- zoning error bugfix
					RepCalc.MakeBar(barNum, i)
					f:Show()
					barNum=barNum+1
				end
			else 
				break
			end
		end
	end
end

function RepCalc.CalcRep(faction, factionID)
        local topVal, earntVal, totalReq, standName, hasBonus, isLFG, factionID
	local name, standingID, barMin, barMax, barValue, hasBonusGain, friendID, friendRep, friendMaxRep, friendReaction, friendThresh, friendNextThresh
	local currentValue, threshold, rewardQuestID, hasRewardPending
	if factionID then
		name, _, standingID, barMin, barMax, barValue, _, _, _, _, _, _, _, _, hasBonusGain = GetFactionInfoByID(factionID)
		friendID, friendRep, friendMaxRep, _, _, _, friendReaction, friendThresh, friendNextThresh = GetFriendshipReputation(factionID)
	else
		for i = 1, 200 do
			name, _, standingID, barMin, barMax, barValue, _, _, _, _, _, _, _, factionID, hasBonusGain = GetFactionInfo(i)
			friendID, friendRep, friendMaxRep, _, _, _, friendReaction, friendThresh, friendNextThresh = GetFriendshipReputation(factionID)
			if name == faction then break end
		end
	end
	totalReq = 42000
	topVal = barMax - barMin
	earntVal = barValue - barMin
	if friendRep then
		standName = friendReaction
		if topVal == 10000 then totalReq = 20000 --Bodyguards
		elseif not friendNextThresh and standingID == 3 then earntVal = 1; topVal = 1 end
	else
		standName = GetText("FACTION_STANDING_LABEL"..standingID, gender)
	end
	totalReq = totalReq - barValue
	hasBonus = hasBonusGain
	if GetLFGBonusFactionID() == factionID then isLFG = true else isLFG = false end
	--Paragon Factions
	if factionID then
		local hasParagon = C_Reputation.IsFactionParagon(factionID)
		if hasParagon then 
			currentValue, threshold, rewardQuestID, hasRewardPending = C_Reputation.GetFactionParagonInfo(factionID)
			standName = "Paragon"; currentValue = mod(currentValue, 10000); totalReq = threshold - currentValue; topVal = threshold; earntVal = currentValue
		end
	end
	return topVal, earntVal, totalReq, standName, hasBonus, isLFG
end

function RepCalc.ShowRep(barNum)
	local x, RC_Bonus, hasTradPost = 0, 1, false
	for i = 1, 100 do
		if RepCalcDB.RepNum[i] == 1 then
			x=x+1
			if x == barNum then idx = i; break end
		end
	end
	--Calc any bonuses
	local _, raceName = UnitRace("player")
	if raceName == "Human" then RC_Bonus = 1.1 end
	local buildings = C_Garrison.GetBuildings(LE_GARRISON_TYPE_6_0)
	for i = 1, #buildings do --Trading post
		local buildingID = buildings[i].buildingID
		if buildingID == 145 then hasTradPost = true end
	end
	--Calc requirements to exalted
	local RepName, RepID = RepCalcDB.RepName[idx], RepCalcDB.RepID[idx]
	if not RepID then
		for i = 1, 200 do
			local name, _, _, _, _, _, _, _, _, _, _, _, _, factionID = GetFactionInfo(i)
			if name == RepName then RepID = factionID; break end
		end
	end
	
	local paragonRep
	if C_Reputation.IsFactionParagon(RepID) then paragonRep = true end

	local RepTop, RepAmt, RepTotal, standName, hasBonus = RepCalc.CalcRep(RepName, RepID)
	if RepTotal == nil or RepTotal <= 0 then return end--Skip if exalted
	local RepRevered, itemAmt, dailyAmt, dailyAmt2, killAmt, killAmt2, itemAmt, itemAmt2, foodAmt = RepTotal-21000
	if RepRevered < 0 then RepRevered = nil end

	local dailyReps = {[909]=250,[1177]=250,[1178]=250,[1174]=250,[1172]=250,[1171]=250,[1015]=250,[1119]=350,[1038]=350,[1073]=350,[1302]=500,[1272]=150,[1337]=130,
	[1269]=100,[1341]=250,[1270]=250,[1376]=150,[1375]=150}
	for k, v in pairs(dailyReps) do -- Dailies Factions
		if k == RepID then
			local dailyAmt, AmtRev = ceil(RepTotal/(v*RC_Bonus))
			if RepRevered then AmtRev = ceil(RepRevered/v) end
			if hasBonus then
				dailyAmt = ceil(dailyAmt/2) 
				if AmtRev then AmtRev = ceil(AmtRev/2) end
			end
			if AmtRev then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." dailies required to reach exalted or "..AmtRev.." to reach revered with "..RepName..".", 0, 0.7, 1)
			else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." dailies required to reach exalted with "..RepName..".", 0, 0.7, 1) end
		end
	end
	local farmReps = {1277,1275,1283,1282,1281,1279,1273,1276,1278,1280}
	for i = 1, 10 do --Tillers Farmers
		if farmReps[i] == RepID then
			local foodAmt = ceil(RepTotal/(1800*RC_Bonus))
			local itemAmt = ceil(RepTotal/(900*RC_Bonus))
			if RepID == 1276 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74649:0:0:0:0:0:0:0:0\124h[Braised Turtle]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79265:0:0:0:0:0:0:0:0\124h[Blue Feather]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1277 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74647:0:0:0:0:0:0:0:0\124h[Valley Stir Fry]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79265:0:0:0:0:0:0:0:0\124h[Blue Feather]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1275 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74651:0:0:0:0:0:0:0:0\124h[Shrimp Dumplings]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79266:0:0:0:0:0:0:0:0\124h[Jade Cat]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1282 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74655:0:0:0:0:0:0:0:0\124h[Twin Fish Platter]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79266:0:0:0:0:0:0:0:0\124h[Jade Cat]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1273 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74643:0:0:0:0:0:0:0:0\124h[Sauteed Carrots]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79267:0:0:0:0:0:0:0:0\124h[Lovely Apple]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1278 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74645:0:0:0:0:0:0:0:0\124h[Eternal Blossom Fish]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79267:0:0:0:0:0:0:0:0\124h[Lovely Apple]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1283 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74654:0:0:0:0:0:0:0:0\124h[Wildfowl Roast]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79268:0:0:0:0:0:0:0:0\124h[Marsh Lily]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1281 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74644:0:0:0:0:0:0:0:0\124h[Swirling Mist Soup]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79268:0:0:0:0:0:0:0:0\124h[Marsh Lily]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1279 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74642:0:0:0:0:0:0:0:0\124h[Charbroiled Tiger Steak]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79264:0:0:0:0:0:0:0:0\124h[Ruby Shard]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
			if RepID == 1280 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..foodAmt.." \124cffffffff\124Hitem:74652:0:0:0:0:0:0:0:0\124h[Fire Spirit Salmon]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79264:0:0:0:0:0:0:0:0\124h[Ruby Shard]\124h\124r hand-ins to become Best Friend with "..RepName..".", 0, 0.7, 1) end
		end
	end
	local bodygReps = {1740,1738,1733,1741,1737,1736,1739}
	for i = 1, 7 do --Bodyguards
		if RepID == bodygReps[i] then
			if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
			killAmt = ceil(RepTotal/(10*RC_Bonus))
			DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..killAmt.." mob kills to reach exalted with "..RepName..".", 0, 0.7, 1)
		end
	end
	--Legion Factions
	if RepID == 1859 then--Nightfallen
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146946::::::::110:::::\124h[Nightfallen Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146900::::::::110:::::\124h[Nightfallen Cache]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146946::::::::110:::::\124h[Nightfallen Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1948 then--Valarjar
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146941::::::::110:::::\124h[Valarjar Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146901::::::::110:::::\124h[Valarjar Strongbox]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146941::::::::110:::::\124h[Valarjar Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1894 then--Wardens
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146945::::::::::0\124h[Wardens Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146902::::::::110:::::\124h[Warden's Supply Kit]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146945::::::::::0\124h[Wardens Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1883 then--Dreamweavers
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146942::::::::110:::::\124h[Dreamweaver Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146898::::::::110:::::\124h[Dreamweaver Cache]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146942::::::::110:::::\124h[Dreamweaver Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1828 then--Highmountain
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146944::::::::110:::::\124h[Highmountain Tribe Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146899::::::::110:::::\124h[Highmountain Supplies]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146944::::::::110:::::\124h[Highmountain Tribe Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1900 then--CourtOfFardondis
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146943::::::::110:::::\124h[Court of Farondis Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:146897::::::::110:::::\124h[Farondis Chest]\124h\124r.", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:146943::::::::110:::::\124h[Court of Farondis Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 2165 then--ArmyoftheLight
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:152958::::::::110:::::\124h[Army of the Light Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 2170 then--ArgussianReach
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests, or "..itemAmt.."x\124cff0070dd\124Hitem:152959::::::::110:::::\124h[Argussian Reach Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 2018 then--TalonsVengeance
		itemAmt = ceil(RepTotal/(100*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cff1eff00\124Hitem:142363::::::::110:::::\124h[Mark of Prey]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1975 then--ConjurerMargoss
		itemAmt = ceil(RepTotal/(50*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:138777::::::::110:::::\124h[Drowned Mana]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 2045 then--ArmiesOfLegionfall
		dailyAmt = ceil(RepTotal/(75*RC_Bonus))
		itemAmt = ceil(RepTotal/(250*RC_Bonus))
		if RepTotal > 21000 then
			itemAmt2 = ceil((RepTotal-21000)/(75*RC_Bonus))
			DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests to reach exalted, or "..itemAmt2.." world quests to reach revered with "..RepName..".", 0, 0.7, 1)
		else
			if paragonRep then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests or "..itemAmt.."x\124cff0070dd\124Hitem:146950::::::::110:::::\124h[Legionfall Insignia]\124h\124r to get your next \124cff0070dd\124Hitem:152108::::::::110:::::\124h[Legionfall Chest]\124h\124r.", 0, 0.7, 1)
			else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." world quests or "..itemAmt.."x\124cff0070dd\124Hitem:146950::::::::110:::::\124h[Legionfall Insignia]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
		end
	end

	if RepID == 609 then--Cenarion Circle
		itemAmt = ceil(RepTotal/(500*RC_Bonus))*10
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:20404:0:0:0:0:0:0:0:0\124h[Encrypted Twilight Text]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1358 then--Nat Pagle
		itemAmt = ceil(RepTotal/(600*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cff1eff00\124Hitem:86542:0:0:0:0:0:0:0:0\124h[Flying Tiger Gourami]\124h\124r, \124cff1eff00\124Hitem:86545:0:0:0:0:0:0:0:0\124h[Mimic Octopus]\124h\124r, or \124cff1eff00\124Hitem:86544:0:0:0:0:0:0:0:0\124h[Spinefish Alpha]\124h\124r to reach Best Friend with Nat Pagle.", 0, 0.7, 1)
	elseif RepID == 978 or RepID == 941 then--Kurenai/The Mag'har
		itemAmt = ceil(RepTotal/(500*RC_Bonus))*10
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:25433:0:0:0:0:0:0:0:0\124h[Obsidian Warbeads]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 933 then--The Consortium
		itemAmt = ceil(RepTotal/(250*RC_Bonus))*10
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:25433:0:0:0:0:0:0:0:0\124h[Obsidian Warbeads]\124h\124r or \124cffffffff\124Hitem:29209:0:0:0:0:0:0:0:0\124h[Zaxxis Insignia]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepID == 970 then--Sporeggar
		itemAmt = ceil(RepTotal/(750*RC_Bonus))*5
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:24246:0:0:0:0:0:0:0:0\124h[Sanguine Hibiscus]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 589 then--Wintersabre Trainers
		RepTotal = RepTotal - 10000
		itemAmt = ceil(RepTotal/1500)
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You have "..itemAmt.." days of daily quests until exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 349 then--Ravenholdt
		itemAmt = ceil(RepTotal/(75*RC_Bonus))*5
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:16885:0:0:0:0:0:0:0:0\124h[Heavy Junkbox]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1031 then--Sha'tari Skyguard
		itemAmt = ceil(RepTotal/(150*RC_Bonus))*6
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:32388:0:0:0:0:0:0:0:0\124h[Shadow Dust]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1168 then --Guild
		itemAmt = ceil(RepTotal/(166.6*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx "..itemAmt.." quest hand-ins ("..ceil(itemAmt/2).." with \124cffa335ee\124Hitem:69210:0:0:0:0:0:0:0:0\124h[Renowned Guild Tabard]\124h\124r) required to reach exalted with your guild.", 0, 0.7, 1)
	elseif RepID == 576 then--Timbermaw Hold
		itemAmt = ceil(RepTotal/(2000*RC_Bonus))*5
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:21383:0:0:0:0:0:0:0:0\124h[Winterfall Spirit Beads]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepID == 990 then--The Scale of the Sands
		itemAmt = ceil(RepTotal/(7800*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx "..itemAmt.." full Hyjal Summit clears to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 934 then--The Scryers
		itemAmt = ceil(RepTotal/(350*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cff1eff00\124Hitem:29739:0:0:0:0:0:0:0:0\124h[Arcane Tome]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 932 then--The Aldor
		itemAmt = ceil(RepTotal/(350*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cff1eff00\124Hitem:29740:0:0:0:0:0:0:0:0\124h[Fel Armament]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepName == RepID == 890 or RepID == 889 then--Silverwing Sentinels/Warsong Outriders
		itemAmt = ceil(RepTotal/(35*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." Warsong Gulch flag captures to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 509 or RepID == 510 then--The League of Arathor/The Defilers
		itemAmt = ceil(RepTotal/(100*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." Arathi Basin wins to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1271 then--Order of the Cloud Serpent
		if hasBonus then RC_Bonus = RC_Bonus*2 end 
		dailyAmt = ceil(RepTotal/(2000*RC_Bonus))
		dailyAmt2 = ceil(RepTotal/(1500*RC_Bonus))
		itemAmt = ceil(RepTotal/(500*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:89155:0:0:0:0:0:0:0:0\124h[Onyx Egg]\124h\124r, or "..dailyAmt.." days of dailies incl. profession-based, or "..dailyAmt2.." days without, to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1492 then--Emperor Shaohao
		dailyAmt = ceil(RepTotal/(250*RC_Bonus))
		killAmt = ceil(RepTotal/(20*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." days of the daily, or "..killAmt.." elite mob kills to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1359 then--The Black Prince
		itemAmt = ceil(RepTotal/(50*RC_Bonus))
		if RepTotal > 21000 then itemAmt2 = ceil((RepTotal-21000)/(50*RC_Bonus)) else itemAmt2 = nil end
		if itemAmt2 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." mob kills to reach exalted or "..itemAmt2.." to reach revered with "..RepName..".", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require approximately "..itemAmt.." mob kills to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1711 then--Steamwheedle Preservation Society
		if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
		itemAmt = ceil(RepTotal/(250*RC_Bonus))*20
		itemAmt2 = ceil(RepTotal/(350*RC_Bonus))
		itemAmt3 = ceil(RepTotal/(500*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cffffffff\124Hitem:118099:0:0:0:0:0:0:0:0:0:0\124h[Gorian Artifact Fragment]\124h\124r, "..itemAmt2.." \124cff0070dd\124Hitem:118100:0:0:0:0:0:0:0:0:0:0\124h[Highmaul Relic]\124h\124r or "..itemAmt3.." epic tokens to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1515 then--Arakkoa Outcasts
		if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
		itemAmt = ceil(RepTotal/(2500*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt.." \124cff0070dd\124Hitem:117492:0:0:0:0:0:0:0:0:0:0\124h[Relic of Rukhmar]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1849 then--Order of the Awakened
		if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
		itemAmt = ceil(RepTotal/(1500*RC_Bonus))
		if RepTotal > 21000 then itemAmt2 = ceil((RepTotal-21000)/(1500*RC_Bonus)) else itemAmt2 = nil end
		if itemAmt2 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." days of \124cffffff00\124Hquest:39433:100\124h[Unseen Influence]\124h\124r to reach exalted or "..itemAmt2.." days to reach revered with "..RepName..".", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." days of \124cffffff00\124Hquest:39433:100\124h[Unseen Influence]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1850 then--The Saberstalkers
		local questVar = "\124cffffff00\124Hquest:39565:100\124h[Rumble in the Jungle]\124h\124r"
		if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
		itemAmt = ceil(RepTotal/(3500*RC_Bonus))
		if RepTotal > 21000 then itemAmt2 = ceil((RepTotal-21000)/(3500*RC_Bonus)) else itemAmt2 = nil end
		if itemAmt2 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." weeks of "..questVar.." to reach exalted or "..itemAmt2.." weeks to reach revered with "..RepName..".", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." weeks of "..questVar.." to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1847 or RepID == 1848 then--Hand of the Prophet/Vol'jin's Headhunters
		if hasTradPost then RC_Bonus = RC_Bonus + 0.2 end
		itemAmt = ceil(RepTotal/(1500*RC_Bonus))
		if RepTotal > 21000 then itemAmt2 = ceil((RepTotal-21000)/(1500*RC_Bonus)) else itemAmt2 = nil end
		if itemAmt2 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." days of dailies to reach exalted or "..itemAmt2.." to reach revered with "..RepName..".", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: "..itemAmt.." days of dailies to reach exalted with "..RepName..".", 0, 0.7, 1) end
	elseif RepID == 1435 then--Shado-Pan Assault
		itemAmt = ceil(RepTotal/(300*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require approximately "..itemAmt.." boss kills to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepID == 1387 or RepID == 1388 then--Kirin Tor Offensive/Sunreaver Onslaught
		local itemAmt = {}
		itemAmt[1] = RepTotal/(1850*RC_Bonus); itemAmt[2] = RepTotal/(1250*RC_Bonus)
		if hasBonus then
			for i = 1, 2 do itemAmt[i] = itemAmt[i]/2 end
		end
		for i = 1, 2 do itemAmt[i] = ceil(itemAmt[i]) end
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..itemAmt[1].." days via PVE dailies or "..itemAmt[2].." days via PVP dailies to reach exalted with "..RepName..".", 0, 0.7, 1)
	end
end